==> apache-servicecomb-service-center-2.0.0-src.tar.gz: apache-servicecomb-service-center-2.0.0-src/datasource/mongo/heartbeat/manager_test.go <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package heartbeat_test

import (
	"testing"

	"github.com/stretchr/testify/assert"

	"github.com/apache/servicecomb-service-center/datasource/mongo/heartbeat"
	_ "github.com/apache/servicecomb-service-center/datasource/mongo/heartbeat/checker"
)

func TestInit(t *testing.T) {
	t.Run("init heartbeat plugin, should not pass", func(t *testing.T) {
		pluginName := heartbeat.ImplName("unknown")
		err := heartbeat.Init(heartbeat.Options{PluginImplName: pluginName})
		assert.Error(t, err)
	})
	t.Run("install and init heartbeat plugin, should pass", func(t *testing.T) {
		pluginName := heartbeat.ImplName("checker")
		err := heartbeat.Init(heartbeat.Options{
			PluginImplName: pluginName,
		})
		assert.NoError(t, err)
	})
}

==> apache-servicecomb-service-center-2.2.0-src.tar.gz: apache-servicecomb-service-center-2.2.0-src/datasource/mongo/heartbeat/manager_test.go <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package heartbeat_test

import (
	"testing"

	"github.com/stretchr/testify/assert"

	"github.com/apache/servicecomb-service-center/datasource/mongo/heartbeat"
	_ "github.com/apache/servicecomb-service-center/datasource/mongo/heartbeat/checker"
)

func TestInit(t *testing.T) {
	t.Run("init unknown heartbeat plugin, should not pass", func(t *testing.T) {
		pluginName := heartbeat.ImplName("unknown")
		err := heartbeat.Init(heartbeat.Options{PluginImplName: pluginName})
		assert.Error(t, err)
	})
	t.Run("install and init checker heartbeat plugin, should pass", func(t *testing.T) {
		pluginName := heartbeat.ImplName("checker")
		err := heartbeat.Init(heartbeat.Options{
			PluginImplName: pluginName,
		})
		assert.NoError(t, err)
	})
}
